@@ -13,13 +13,13 @@ from zipfile import ZipFile
 
 import pandas
 import requests
-from requests_oauthlib import OAuth2Session
-
 from hsmodels.schemas import load_rdf, rdf_string
 from hsmodels.schemas.base_models import BaseMetadata
 from hsmodels.schemas.enums import AggregationType
 from hsmodels.schemas.fields import BoxCoverage, PointCoverage
-from hsmodels.schemas.json_models import ResourcePreview, User
+from requests_oauthlib import OAuth2Session
+
+from hsclient.json_models import ResourcePreview, User
 from hsclient.utils import attribute_filter, encode_resource_url, is_aggregation, main_file_type
 
 
@@ -880,7 +880,6 @@ class HydroShare:
 
         res = response.json()
         results = res['results']
-        print(res['count'])
         for item in results:
             yield ResourcePreview(**item)
 
